@@ -12,7 +12,7 @@ import dns
 import cron
 
 default_bin_path = '/usr/local/bin'
-default_config_path = '/etc/insider'
+default_config_path = '/usr/local/insider/config'
 default_logs_path = '/var/log'
 
 
